
.. image:: https://img.shields.io/pypi/v/mirge3.svg?branch=master
    :target: https://pypi.python.org/pypi/mirge3
    :alt:
    
.. image:: https://img.shields.io/badge/install%20with-bioconda-brightgreen.svg?style=flat
    :target: http://bioconda.github.io/recipes/mirge3/README.html
    :alt: install with bioconda
    
.. image:: https://anaconda.org/bioconda/mirge3/badges/latest_release_date.svg   
    :target: https://anaconda.org/bioconda/mirge3   
    
.. image:: https://camo.githubusercontent.com/ec0ce88c34009d95029a49d265b89d03d9357ed953885164d6e037c1ccb8892b/68747470733a2f2f696d672e736869656c64732e696f2f636f6e64612f646e2f62696f636f6e64612f6d69726765332e737667   
    :target: https://anaconda.org/bioconda/mirge3/files
       

    


========
miRge3.0
========

An update to Python package to perform comprehensive analysis of small RNA sequencing data, including miRNA annotation, A-to-I editing, novel miRNA detection, isomiR analysis, visualization through IGV, processing Unique Molecular Identifieres (UMI), tRF detection and producing interactive graphical output.

miRge3.0 is developed in python v3.8 and is a recent update of our previous version `miRge2.0 <https://pubmed.ncbi.nlm.nih.gov/30153801>`_. This build includes command line interface (CLI) and cross-platform Graphical User Interface (GUI). For more details refer to documentation link below.  

Links
-----

* `Documentation <https://mirge3.readthedocs.io/en/master/>`_
* `miRge3.0 Libraries <https://mirge3.readthedocs.io/en/latest/quick_start.html#mirge3-0-libraries>`_ 
* `Source code <https://github.com/mhalushka/mirge3.0/>`_
* `Frequently asked questions <https://mirge3.readthedocs.io/en/latest/faqs.html>`_
* `Report an issue <https://github.com/mhalushka/mirge3.0/issues>`_
* `Project page on PyPI <https://pypi.python.org/pypi/mirge3/>`_

========
Citation
========

Arun H Patil, Marc K Halushka. **miRge3.0: a comprehensive microRNA and tRF sequencing analysis pipeline**. `NAR Genomics and Bioinformatics  <https://academic.oup.com/nargab/article/3/3/lqab068/6325159>`_. 2021.

